# -*- coding: utf-8 -*-
##############################################################################
#
#    Author: Yannick Vaucher (Camptocamp) 
#    Contributor: 
#    Copyright 2011 Camptocamp SA
#    Donors:
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
from crm.wizard.crm_lead_to_partner import crm_lead2partner


def create_partner_replacement(self, cr, uid, ids, context=None):
    """
    Replacement of wizard crm_lead2partner method to split contact_name in
    firstname, lastname

    This function Creates partner based on action.
    @param self: The object pointer
    @param cr: the current row, from the database cursor,
    @param uid: the current user’s ID for security checks,
    @param ids: List of Lead to Partner's IDs
    @param context: A standard dictionary for contextual values

    @return : Dictionary {}.
    """
    if context is None:
        context = {}

    lead_obj = self.pool.get('crm.lead')
    partner_obj = self.pool.get('res.partner')
    contact_obj = self.pool.get('res.partner.address')
    partner_ids = []
    partner_id = False
    contact_id = False
    rec_ids = context and context.get('active_ids', [])

    for data in self.browse(cr, uid, ids, context=context):
        for lead in lead_obj.browse(cr, uid, rec_ids, context=context):
            if data.action == 'create':
                partner_id = partner_obj.create(cr, uid, {
                    'name': lead.partner_name or 
                            (lead.firstname or lead.lastname) 
                            and lead.firstname + " " + lead.lastname
                            or lead.firstname or lead.lastname 
                            or lead.name,
                    'user_id': lead.user_id.id,
                    'comment': lead.description,
                    })
                contact_id = contact_obj.create(cr, uid, {
                    'partner_id': partner_id,
                    'firstname': lead.firstname,
                    'lastname': lead.lastname,
                    'phone': lead.phone,
                    'mobile': lead.mobile,
                    'email': lead.email_from,
                    'fax': lead.fax,
                    'title': lead.title and lead.title.id or False,
                    'function': lead.function,
                    'street': lead.street,
                    'street2': lead.street2,
                    'zip': lead.zip,
                    'city': lead.city,
                    'country_id': lead.country_id and lead.country_id.id or False,
                    'state_id': lead.state_id and lead.state_id.id or False,
                })

            else:
                if data.partner_id:
                    partner_id = data.partner_id.id
                    contact_id = partner_obj.address_get(cr, uid, [partner_id])['default']

            partner_ids.append(partner_id)

            if data.action<>'no':
                vals = {}
                if partner_id:
                    vals.update({'partner_id': partner_id})
                if contact_id:
                    vals.update({'partner_address_id': contact_id})
                lead_obj.write(cr, uid, [lead.id], vals)
    return partner_ids

# Here we replace the method
crm_lead2partner._create_partner = create_partner_replacement
